@@ -29,6 +29,7 @@ import gde.exception.TimeOutException;
 import gde.log.Level;
 import gde.ui.DataExplorer;
 import gde.utils.Checksum;
+import gde.utils.StringHelper;
 
 /**
  * eStation serial port implementation
@@ -52,7 +53,6 @@ public class CSV2SerialPort extends DeviceCommPort implements IDeviceCommPort {
 	long								time						= 0;
 	boolean							isDataReceived	= false;
 	int									index						= 0;
-	boolean 						isEndByte_1 		= false;
 	
 	final boolean				isSerialRequest;
 	final byte[]				serialRequest;
@@ -75,6 +75,8 @@ public class CSV2SerialPort extends DeviceCommPort implements IDeviceCommPort {
 		this.tmpData = new byte[0];
 		this.isSerialRequest = this.device.getDeviceConfiguration().isSerialPortRequest();
 		this.serialRequest = this.device.getDeviceConfiguration().getSerialPortRequest();
+		if (log.isLoggable(Level.FINE))
+			log.log(Level.FINE, "EOL " + StringHelper.byte2Hex2CharString(this.device.getDataBlockEnding(), this.device.getDataBlockEnding().length));
 	}
 
 	/**
@@ -94,19 +96,7 @@ public class CSV2SerialPort extends DeviceCommPort implements IDeviceCommPort {
 			readNewData();
 
 			//find start index
-			while (this.index < this.answer.length && this.answer[this.index] != this.startByte)
-				++this.index;
-
-			if (this.index < this.answer.length) {
-				startIndex = this.index;
-				++this.index;
-				this.tmpData = new byte[0];
-			}
-			else { //startIndex not found, read new data
-				this.isDataReceived = false;
-				this.index = 0;
-				return getData();
-			}
+			startIndex = findStartIndex(0);
 
 			//find end index
 			findDataEnd(startIndex);
@@ -117,9 +107,38 @@ public class CSV2SerialPort extends DeviceCommPort implements IDeviceCommPort {
 			}
 			throw e;
 		}
+		log.log(Level.INFO, "return received data");
+		this.isDataReceived = false;
 		return this.data;
 	}
 
+	/**
+	 * recursive find start character index
+	 * @param searchIndex
+	 * @return startIndex
+	 * @throws IOException
+	 * @throws TimeOutException
+	 */
+	private int findStartIndex(int searchIndex) throws IOException, TimeOutException {
+		this.index = searchIndex;
+		while (this.index < this.answer.length && this.answer[this.index] != this.startByte)
+			++this.index;
+		
+		if (this.index < this.answer.length) {
+			searchIndex = this.index;
+			++this.index;
+			this.tmpData = new byte[0];
+		}
+		else { //startIndex not found, read new data
+			log.log(Level.WARNING, "startIndex not found, check leading character defined");
+			this.isDataReceived = false;
+			//this.index = 0;
+			readNewData();
+			return findStartIndex(0);
+		}
+		return searchIndex;
+	}
+	
 	/**
 	 * recursive find the end of data, normal exit is not at the end of the method
 	 * @param startIndex
@@ -129,17 +148,19 @@ public class CSV2SerialPort extends DeviceCommPort implements IDeviceCommPort {
 	protected byte[] findDataEnd(int startIndex) throws IOException, TimeOutException {
 		final String $METHOD_NAME = "findDataEnd";
 		int endIndex;
-		while (this.index < this.answer.length && !((this.endByte_1 != 0x00 || this.answer[this.index - 1] == this.endByte_1 || isEndByte_1 == true) && this.answer[this.index] == this.endByte))
-			++this.index;
+		if (this.endByte_1 != 0x00) {//two char line ending CR/LF
+			while (this.index < this.answer.length && !((this.endByte_1 != 0x00 || this.answer[this.index - 1] == this.endByte_1) && this.answer[this.index] == this.endByte))
+				++this.index;
+		}
+		else {//this.endByte_1 == 0x00 -> single line end character
+			while (this.index < this.answer.length && !(this.answer[this.index] == this.endByte))
+				++this.index;
+		}
 		
-		if (this.endByte_1 != 0x00 || this.answer[this.index - 1] == this.endByte_1)
-			isEndByte_1 = true;
-
 		if (this.index < this.answer.length && (this.tmpData.length + this.index - startIndex) > 8) {
-			endIndex = this.index;
-			isEndByte_1 = false;
+			endIndex = this.index > 1 && this.endByte_1 != 0x00 && this.answer[this.index] == this.endByte ? this.index-=1 : this.index;
 			this.data = new byte[this.tmpData.length + endIndex - startIndex];
-			//System.out.println(startIndex + " - " + this.tmpData.length + " - " + endIndex);
+			if (log.isLoggable(Level.FINER)) log.log(Level.FINER, this.tmpData.length + " + " + endIndex + " - " + startIndex);
 			System.arraycopy(this.tmpData, 0, this.data, 0, this.tmpData.length);
 			System.arraycopy(this.answer, startIndex, this.data, this.tmpData.length, endIndex - startIndex);
 			if (CSV2SerialPort.log.isLoggable(Level.FINER)) {
@@ -154,6 +175,7 @@ public class CSV2SerialPort extends DeviceCommPort implements IDeviceCommPort {
 			return this.data;
 		}
 		//endIndex not found, save temporary data, read new data
+		log.log(Level.INFO,"endIndex not found, save temporary data, read new data " );
 		this.data = new byte[this.tmpData.length];
 		System.arraycopy(this.tmpData, 0, this.data, 0, this.data.length);
 
@@ -178,6 +200,8 @@ public class CSV2SerialPort extends DeviceCommPort implements IDeviceCommPort {
 			this.answer = new byte[this.tmpDataLength];
 			this.answer = this.read(this.answer, this.timeout, this.stableIndex);
 			this.isDataReceived = true;
+			if (log.isLoggable(Level.FINE))
+					log.log(Level.FINE, StringHelper.byte2Hex2CharString(this.answer, this.answer.length));
 		}
 	}
 
