@@ -18,6 +18,11 @@
 ****************************************************************************************/
 package gde.device.wb;
 
+import java.io.IOException;
+import java.util.logging.Logger;
+
+import org.eclipse.swt.SWT;
+
 import gde.GDE;
 import gde.data.Channel;
 import gde.data.Channels;
@@ -31,17 +36,14 @@ import gde.exception.DevicePropertiesInconsistenceException;
 import gde.exception.SerialPortException;
 import gde.exception.TimeOutException;
 import gde.io.DataParser;
+import gde.io.IDataParser;
+import gde.io.JsonDataParser;
 import gde.log.Level;
 import gde.messages.Messages;
 import gde.ui.DataExplorer;
 import gde.utils.TimeLine;
 import gde.utils.WaitTimer;
 
-import java.io.IOException;
-import java.util.logging.Logger;
-
-import org.eclipse.swt.SWT;
-
 /**
  * Thread implementation to gather data from eStation device
  * @author Winfied Brügmann
@@ -55,7 +57,7 @@ public class GathererThread extends Thread {
 	final CSV2SerialPort		serialPort;
 	final CSV2SerialAdapter	device;
 	final Channels					channels;
-	final DataParser				parser;
+	final IDataParser				parser;
 	
 	Channel									activeChannel;
 	RecordSet								activeRecordSet;
@@ -83,7 +85,11 @@ public class GathererThread extends Thread {
 		this.channelNumber = channelConfigNumber;
 		this.channel = this.channels.get(this.channelNumber);
 		this.recordSetKey = GDE.STRING_BLANK + this.device.getRecordSetStateNameReplacement(this.stateNumber);
-		this.parser = new DataParser(this.device.getDataBlockTimeUnitFactor(), this.device.getDataBlockLeader(), this.device.getDataBlockSeparator().value(), this.device.getDataBlockCheckSumType(), this.device.getDataBlockSize(InputTypes.FILE_IO)); //$NON-NLS-1$  //$NON-NLS-2$
+		if (this.device.getSerialPortType().getRespond() != null && this.device.getSerialPortType().getRespond().name().equals("JSON"))
+				this.parser = new JsonDataParser(this.device.getDataBlockTimeUnitFactor(), this.device.getDataBlockLeader(), this.device.getDataBlockSeparator().value(), this.device.getDataBlockCheckSumType(), this.device.getDataBlockSize(InputTypes.FILE_IO)); //$NON-NLS-1$  //$NON-NLS-2$
+		else {
+			this.parser = new DataParser(this.device.getDataBlockTimeUnitFactor(), this.device.getDataBlockLeader(), this.device.getDataBlockSeparator().value(), this.device.getDataBlockCheckSumType(), this.device.getDataBlockSize(InputTypes.FILE_IO)); //$NON-NLS-1$  //$NON-NLS-2$
+		}
 
 		if (!this.serialPort.isConnected()) {
 			this.serialPort.open();
@@ -116,7 +122,7 @@ public class GathererThread extends Thread {
 		catch (IOException e) {
 			log.log(java.util.logging.Level.SEVERE, e.getMessage(), e);
 		}
-		lastTmpCycleTime = System.nanoTime()/1000000;
+		startCycleTime = lastTmpCycleTime = System.currentTimeMillis();
 		while (!this.serialPort.isInterruptedByUser) {
 			try {
 				if (this.application != null) this.application.setPortConnected(true);
@@ -125,11 +131,12 @@ public class GathererThread extends Thread {
 						break;
 					// get data from device
 					dataBuffer = this.serialPort.getData();
+					if (log.isLoggable(Level.FINE)) log.log(Level.FINE, new String(dataBuffer));
 					// check if device is ready for data capturing else wait for 180 seconds max. for actions
-					
+					this.parser.parse(new String(dataBuffer), 42);					
 					try {
-						this.channelNumber = Integer.valueOf(GDE.STRING_EMPTY+(char)dataBuffer[1]);
-						this.stateNumber = Integer.valueOf(GDE.STRING_EMPTY+(char)dataBuffer[3]);
+						this.channelNumber = this.parser.getChannelConfigNumber();
+						this.stateNumber = this.parser.getState();
 						if (log.isLoggable(Level.FINE)) log.logp(Level.FINE, GathererThread.$CLASS_NAME, $METHOD_NAME,	device.getChannelCount() + " - data for channel = " + channelNumber + " state = " + stateNumber);
 						if (this.channelNumber > device.getChannelCount()) 
 							continue; //skip data if not configured
@@ -179,16 +186,14 @@ public class GathererThread extends Thread {
 						measurementCount = 0;
 						startCycleTime = 0;
 					}
-
 					// prepare the data for adding to record set
-					tmpCycleTime = System.nanoTime()/1000000;
+					tmpCycleTime = System.currentTimeMillis();
 					if (measurementCount++ == 0) {
 						startCycleTime = tmpCycleTime;
 					}
- 
+
 					if (channelRecordSet != null) {
 						if (this.serialPort.isInterruptedByUser) break;
-						this.parser.parse(new String(dataBuffer), 42);
 						if (this.parser.getValues().length == channelRecordSet.size()) 
 							channelRecordSet.addPoints(this.parser.getValues(), (tmpCycleTime - startCycleTime));
 						else
@@ -210,19 +215,17 @@ public class GathererThread extends Thread {
 					}
 				}
 				if (deviceTimeStep_ms > 0) { //time step is constant
-					delayTime = (long) ((deviceTimeStep_ms - 3) - (tmpCycleTime - lastTmpCycleTime));
+					delayTime = (long) (deviceTimeStep_ms - (System.currentTimeMillis() - lastTmpCycleTime));
 					if (delayTime > 0) {
 						WaitTimer.delay(delayTime);
 					}
-					lastTmpCycleTime = tmpCycleTime;
+					if (log.isLoggable(Level.TIME)) log.logp(Level.TIME, GathererThread.$CLASS_NAME, $METHOD_NAME, "delayTime = " + TimeLine.getFomatedTimeWithUnit(delayTime)); //$NON-NLS-1$
+					lastTmpCycleTime = System.currentTimeMillis();;
 				}
-				if (log.isLoggable(Level.TIME)) log.logp(Level.TIME, GathererThread.$CLASS_NAME, $METHOD_NAME, "delayTime = " + TimeLine.getFomatedTimeWithUnit(delayTime)); //$NON-NLS-1$
-				if (log.isLoggable(Level.TIME)) log.logp(Level.TIME, GathererThread.$CLASS_NAME, $METHOD_NAME, "time = " + TimeLine.getFomatedTimeWithUnit(tmpCycleTime - startCycleTime)); //$NON-NLS-1$
+				if (log.isLoggable(Level.TIME)) log.logp(Level.TIME, GathererThread.$CLASS_NAME, $METHOD_NAME, "time = " + TimeLine.getFomatedTimeWithUnit(lastTmpCycleTime - startCycleTime)); //$NON-NLS-1$
 			}
 			catch (DataInconsitsentException e) {
 				log.log(Level.WARNING, e.getMessage(), e);
-				//String message = Messages.getString(gde.messages.MessageIds.GDE_MSGE0036, new Object[] {this.getClass().getSimpleName(), $METHOD_NAME}); 
-				//cleanup(message);
 			}
 			catch (Throwable e) {
 				if (!this.serialPort.isInterruptedByUser) {
@@ -250,7 +253,10 @@ public class GathererThread extends Thread {
 				}
 			}
 		}
-		this.application.setStatusMessage(""); //$NON-NLS-1$
+		if (this.application != null) {
+			this.application.setPortConnected(false);
+			this.application.setStatusMessage(""); //$NON-NLS-1$
+		}
 		log.logp(Level.FINE, GathererThread.$CLASS_NAME, $METHOD_NAME, "======> exit"); //$NON-NLS-1$
 	}
 
@@ -274,18 +280,8 @@ public class GathererThread extends Thread {
 				if (recordSet != null && recordSet.getRecordDataSize(true) > 5) { // some other exception while program execution, record set has data points
 					finalizeRecordSet(recordSet, false);
 					if (enableEndMessage) 
-						this.application.openMessageDialog(Messages.getString(MessageIds.GDE_MSGT1709));
+						this.application.openMessageDialog(Messages.getString(gde.device.wb.MessageIds.GDE_MSGT1709));
 				}
-//				else {
-//					if (throwable != null) {
-//						cleanup(Messages.getString(gde.messages.MessageIds.GDE_MSGE0022, new Object[] { throwable.getClass().getSimpleName(), throwable.getMessage() })
-//								+ Messages.getString(MessageIds.GDE_MSGT1708));
-//					}
-//					else {
-//						if (enableEndMessage)
-//							cleanup(Messages.getString(gde.messages.MessageIds.GDE_MSGE0026)	+ Messages.getString(MessageIds.GDE_MSGT1708));
-//					}
-//				}
 			}
 		}
 		finally {
