@@ -85,7 +85,7 @@ public class GDE {
 		}
 
 		public void setProgress(int percentage) {
-			String sThreadId = String.format("%06d", Thread.currentThread().getId());
+			String sThreadId = String.format("%06d", Thread.currentThread().getId()); //release >= 19 -> threadId()
 			application.setProgress(percentage, sThreadId);
 		}
 
@@ -106,13 +106,13 @@ public class GDE {
 	private static boolean									isWithUi													= false;
 
 	// ****** begin global constants section *******
-	public static final String							VERSION														= "Version 3.8.6"; // check device update list in settings getServiceUpdateList()																																																			//$NON-NLS-1$
+	public static final String							VERSION														= "Version 3.9.0"; // check device update list in settings getServiceUpdateList()																						//$NON-NLS-1$
 	public static final int									VERSION_NUMBER										= GDE.VERSION.contains("beta") 
 															? Integer.parseInt(GDE.VERSION.substring(8, 8+5).replace(GDE.STRING_DOT, GDE.STRING_EMPTY)) - 1
 															: Integer.parseInt(GDE.VERSION.substring(8, 8+5).replace(GDE.STRING_DOT, GDE.STRING_EMPTY));
 	public static final String							NAME_SHORT												= "GDE";																																																										//$NON-NLS-1$
 	public static final String							NAME_LONG													= "DataExplorer";																																																						//$NON-NLS-1$
-	public final static String							DEVICE_PROPERTIES_XSD_VERSION			= "_V48";																																																										//$NON-NLS-1$
+	public final static String							DEVICE_PROPERTIES_XSD_VERSION			= "_V49";																																																										//$NON-NLS-1$
 	public final static String							GRAPHICS_TEMPLATES_XSD_VERSION		= "_V08";																																																										//$NON-NLS-1$
 	public final static String							HISTO_CACHE_ENTRIES_XSD_VERSION		= "_V04";																																																										//$NON-NLS-1$
 	public final static String							CLEAN_SETTINGS_WHILE_SHUTDOWN			= "CLEAN_SETTINGS_WHILE_SHUTDOWN";
@@ -238,6 +238,7 @@ public class GDE {
 	public static final String							FILE_ENDING_STAR_LOV							= "*.lov";																																																									//$NON-NLS-1$
 	public static final String							FILE_ENDING_STAR_OSD							= "*.osd";																																																									//$NON-NLS-1$
 	public static final String							FILE_ENDING_STAR_CSV							= "*.csv";																																																									//$NON-NLS-1$
+	public static final String							FILE_ENDING_STAR_JSON							= "*.json";																																																									//$NON-NLS-1$
 	public static final String							FILE_ENDING_STAR_IGC							= "*.igc";																																																									//$NON-NLS-1$
 	public static final String							FILE_ENDING_STAR_JPG							= "*.jpg";																																																									//$NON-NLS-1$
 	public static final String							FILE_ENDING_STAR_PNG							= "*.png";																																																									//$NON-NLS-1$
@@ -257,6 +258,7 @@ public class GDE {
 	public static final String							FILE_ENDING_DOT_LOV								= ".lov";																																																										//$NON-NLS-1$
 	public static final String							FILE_ENDING_DOT_OSD								= ".osd";																																																										//$NON-NLS-1$
 	public static final String							FILE_ENDING_DOT_CSV								= ".csv";																																																										//$NON-NLS-1$
+	public static final String							FILE_ENDING_DOT_JSON							= ".json";																																																										//$NON-NLS-1$
 	public static final String							FILE_ENDING_DOT_IGC								= ".igc";																																																										//$NON-NLS-1$
 	public static final String							FILE_ENDING_DOT_NMEA							= ".nmea";																																																									//$NON-NLS-1$
 	public static final String							FILE_ENDING_DOT_JPG								= ".jpg";																																																										//$NON-NLS-1$
@@ -282,6 +284,7 @@ public class GDE {
 	public static final String							FILE_ENDING_LOV										= "lov";																																																										//$NON-NLS-1$
 	public static final String							FILE_ENDING_OSD										= "osd";																																																										//$NON-NLS-1$
 	public static final String							FILE_ENDING_CSV										= "csv";																																																										//$NON-NLS-1$
+	public static final String							FILE_ENDING_JSON									= "json";																																																										//$NON-NLS-1$
 	public static final String							FILE_ENDING_IGC										= "igc";																																																										//$NON-NLS-1$
 	public static final String							FILE_ENDING_NMEA									= "nmea";																																																										//$NON-NLS-1$
 	public static final String							FILE_ENDING_XML										= "xml";																																																										//$NON-NLS-1$
@@ -430,7 +433,7 @@ public class GDE {
 
 	public final static Map<String, String>	deviceMap													= new HashMap<String, String>();
 
-	/** access to progrss bar and status message  */
+	/** access to progress bar and status message  */
 	public static UiNotification						uiNotification;
 
 	private static Thread										settingsThread;
@@ -461,6 +464,7 @@ public class GDE {
 		try {
 			System.setProperty("https.protocols", "SSLv3,TLSv1,TLSv1.1,TLSv1.2");
 			System.setProperty("file.encoding", "UTF-8");
+			System.setProperty("fazecast.jSerialComm.appid", "GDE");
 			GDE.initLogger();
 			log.log(Level.INFO, "initLogger  done ");
 
@@ -536,12 +540,12 @@ public class GDE {
 					? ((String)props.get("java.vm.specification.version")).substring(2) : ((String)props.get("java.vm.specification.version")));
 			
 			if (IS_ARCH_DATA_MODEL_64 || IS_OS_ARCH_ARM) {
-				if (javaVmSpecificationVersion < 11 || javaVmSpecificationVersion > 17) {
+				if (javaVmSpecificationVersion < 17 || javaVmSpecificationVersion > 21) {
 					application.openMessageDialogAsync(Messages.getString(MessageIds.GDE_MSGW0050, new Integer[] { javaVmSpecificationVersion }));
 				}
 			}
 			else {
-				if (javaVmSpecificationVersion < 8 || javaVmSpecificationVersion > 17) {
+				if (javaVmSpecificationVersion < 8 || javaVmSpecificationVersion > 21) {
 					application.openMessageDialogAsync(Messages.getString(MessageIds.GDE_MSGW0050, new Integer[] { javaVmSpecificationVersion }));
 				}
 			}
@@ -583,12 +587,12 @@ public class GDE {
 			}
 			for (String path : files) {
 				if (!path.startsWith(GDE.STRING_DOT)) if (new File(basePath + path + GDE.STRING_WITHIN_ECLIPSE).exists())
-					urls.add(new URL("file:" + basePath + path + GDE.STRING_WITHIN_ECLIPSE)); //$NON-NLS-1$
+					urls.add(new File(basePath + path + GDE.STRING_WITHIN_ECLIPSE).toURI().toURL()); //$NON-NLS-1$
 				else if (new File(basePath + path + "/lib").exists()) {
 					try {
 						List<File> jarFiles = FileUtils.getFileListing(new File(basePath + path + "/lib/"), 1);
 						for (File jarFile : jarFiles) {
-							if (jarFile.getName().startsWith("HoTT") && jarFile.getName().endsWith(GDE.FILE_ENDING_DOT_JAR)) urls.add(new URL("file:" + basePath + path + "/lib/" + jarFile.getName())); //$NON-NLS-2$
+							if (jarFile.getName().startsWith("HoTT") && jarFile.getName().endsWith(GDE.FILE_ENDING_DOT_JAR)) urls.add(new File(basePath + path + "/lib/" + jarFile.getName()).toURI().toURL()); //$NON-NLS-2$
 						}
 					}
 					catch (FileNotFoundException e) {
