@@ -96,14 +96,15 @@ public class DeviceCommPort implements IDeviceCommPort {
 						: (System.getProperty("GDE_SIMULATION_TIME_STEP_MSEC") != null ? Integer.parseInt(System.getProperty("GDE_SIMULATION_TIME_STEP_MSEC")) : (int)this.device.getTimeStep_ms())));
 		}
 		else  if (this.deviceConfig.getSerialPortType() != null) {
-			if (this.settings.isRXTXcommToBeUsed()) //RXTXcomm
-				this.port = new DeviceSerialPortImpl(this.deviceConfig, this.application);
-			else //jSerialCommPort: 
-				this.port = new DeviceJavaSerialCommPortImpl(this.deviceConfig, this.application);
+			//jSerialComm Port: 
+			this.port = new DeviceJavaSerialCommPortImpl(this.deviceConfig, this.application);
 		}
 		else if (this.deviceConfig.getUsbPortType() != null) { // USB device
 			this.port = new DeviceUsbPortImpl(this.deviceConfig, this.application);
 		}
+		else if (this.deviceConfig.getTcpPortType() != null) { // TCP connected device
+			this.port = new DeviceTcpPortImpl(this.deviceConfig, this.application);
+		}
 		else this.port = null;
 		
 		DeviceCommPort.staticPort = this.port;
@@ -125,17 +126,30 @@ public class DeviceCommPort implements IDeviceCommPort {
 						: (System.getProperty("GDE_SIMULATION_TIME_STEP_MSEC") != null ? Integer.parseInt(System.getProperty("GDE_SIMULATION_TIME_STEP_MSEC")) : (int)this.deviceConfig.getTimeStep_ms())));
 		}
 		else  if (this.deviceConfig.getSerialPortType() != null) {
-			//RXTXcomm usage: this.port = new DeviceSerialPortImpl(this.deviceConfig, this.application);
 			//jSerialCommPort: 
 			this.port = new DeviceJavaSerialCommPortImpl(this.deviceConfig, this.application);
 		}
 		else if (this.deviceConfig.getUsbPortType() != null) { // USB device
 			this.port = new DeviceUsbPortImpl(this.deviceConfig, this.application);
 		}
+		else if (this.deviceConfig.getTcpPortType() != null) { // TCP connected device
+			this.port = new DeviceTcpPortImpl(this.deviceConfig, this.application);
+		}
 		else this.port = null;
 
 		DeviceCommPort.staticPort = this.port;
 	}
+	
+	/**
+	 * constructor to enable serial port tests without complete device construction
+	 */
+	public DeviceCommPort() {
+		this.device = null;
+		this.deviceConfig = null;
+		this.application = null;
+		this.settings = null;
+		this.port = null;
+	}
 
 	/**
 	 * updates the given vector with actual available according black/white list configuration
@@ -144,9 +158,7 @@ public class DeviceCommPort implements IDeviceCommPort {
 	 * @param portWhiteList
 	 */
 	public static TreeMap<String, String> listConfiguredSerialPorts(final boolean doAvialabilityCheck, final String portBlackList, final Vector<String> portWhiteList) {
-		if (DeviceCommPort.staticPort != null && DeviceCommPort.staticPort instanceof DeviceSerialPortImpl) //RXTXcomm
-			return DeviceSerialPortImpl.listConfiguredSerialPorts(doAvialabilityCheck, portBlackList, portWhiteList);
-		else if (DeviceCommPort.staticPort != null && DeviceCommPort.staticPort instanceof DeviceJavaSerialCommPortImpl) //JSerialCommPort: 
+		if (DeviceCommPort.staticPort != null && DeviceCommPort.staticPort instanceof DeviceJavaSerialCommPortImpl) //JSerialCommPort: 
 			return DeviceJavaSerialCommPortImpl.listConfiguredSerialPorts(doAvialabilityCheck, portBlackList, portWhiteList);
 		else {
 			DeviceCommPort.availablePorts.clear();
@@ -159,9 +171,7 @@ public class DeviceCommPort implements IDeviceCommPort {
 	 * @return available serial port list
 	 */
 	public static String[] prepareSerialPortList() {
-		if (DeviceCommPort.staticPort != null && DeviceCommPort.staticPort instanceof DeviceSerialPortImpl) //RXTXcomm
-			return DeviceSerialPortImpl.prepareSerialPortList();
-		else if (DeviceCommPort.staticPort != null && DeviceCommPort.staticPort instanceof DeviceJavaSerialCommPortImpl) //JSerialCommPort: 
+		if (DeviceCommPort.staticPort != null && DeviceCommPort.staticPort instanceof DeviceJavaSerialCommPortImpl) //JSerialCommPort: 
 			return DeviceJavaSerialCommPortImpl.prepareSerialPortList();
 		else
 			return new String[0];
