@@ -67,7 +67,7 @@ import gde.utils.WaitTimer;
  * DeviceSerialPort is the abstract class of the serial port implementation as parent for a device specific serial port implementation
  * @author Winfried Brügmann
  */
-public class DeviceJavaSerialCommPortImpl implements IDeviceCommPort, SerialPortPacketListener {
+public class DeviceJavaSerialCommPortImpl extends DeviceCommPort implements IDeviceCommPort, SerialPortPacketListener {
 	final static String										$CLASS_NAME								= DeviceJavaSerialCommPortImpl.class.getName();
 	final static Logger										log												= Logger.getLogger(DeviceJavaSerialCommPortImpl.$CLASS_NAME);
 
