@@ -46,6 +46,8 @@ import org.eclipse.swt.widgets.FileDialog;
 import org.usb4java.DeviceHandle;
 import org.usb4java.LibUsbException;
 
+import com.fazecast.jSerialComm.SerialPort;
+
 import gde.GDE;
 import gde.config.Settings;
 import gde.device.FormatTypes;
@@ -64,12 +66,11 @@ import gde.ui.DataExplorer;
 import gde.utils.FileUtils;
 import gde.utils.StringHelper;
 import gde.utils.WaitTimer;
-import gnu.io.SerialPort;
 
 /**
  * class to simulate serial port where bytes read form input file
  */
-public class DeviceSerialPortSimulatorImpl implements IDeviceCommPort {
+public class DeviceSerialPortSimulatorImpl extends DeviceCommPort implements IDeviceCommPort {
 	final static String	$CLASS_NAME					= DeviceSerialPortSimulatorImpl.class.getName();
 	final static Logger	log									= Logger.getLogger($CLASS_NAME);
 
