@@ -39,6 +39,8 @@ import org.usb4java.DeviceList;
 import org.usb4java.LibUsb;
 import org.usb4java.LibUsbException;
 
+import com.fazecast.jSerialComm.SerialPort;
+
 import gde.GDE;
 import gde.config.Settings;
 import gde.device.DeviceConfiguration;
@@ -53,9 +55,8 @@ import gde.messages.Messages;
 import gde.ui.DataExplorer;
 import gde.ui.dialog.UsbDeviceSelectionDialog;
 import gde.utils.WaitTimer;
-import gnu.io.SerialPort;
 
-public class DeviceUsbPortImpl implements IDeviceCommPort {
+public class DeviceUsbPortImpl extends DeviceCommPort implements IDeviceCommPort {
 	private final static Logger					log							= Logger.getLogger(DeviceUsbPortImpl.class.getName());
 
 	final protected DeviceConfiguration	deviceConfig;
@@ -91,6 +92,8 @@ public class DeviceUsbPortImpl implements IDeviceCommPort {
 		this.settings = null;
 	}
 
+	//// unused serial port methods
+	
 	public SerialPort open() throws ApplicationConfigurationException, SerialPortException {
 		// Auto-generated method stub
 		return null;
@@ -195,6 +198,8 @@ public class DeviceUsbPortImpl implements IDeviceCommPort {
 		return 0;
 	}
 
+	/////// USB interface starts here
+
 	/**
 	 * find USB device to be identified by vendor ID and product ID
 	 * @param vendorId
